@@ -640,6 +640,8 @@ static void prexpr(node *np, FILE *fp)
 
     case ONESPOT:
     case TWOSPOT:
+    case TAIL:
+    case HYBRID:
 	prvar(np, fp);
 	break;
 
@@ -720,7 +722,7 @@ static void emit_guard(tuple *tn, FILE *fp)
     (void) fprintf(fp, "    if (");
     if (tn->exechance < 100)
 	(void) fprintf(fp, "roll(%d) && ", tn->exechance);
-    (void) fprintf(fp, "!abstained[%d]) {\n", tn - tuples);
+    (void) fprintf(fp, "!abstained[%d]) {\n", (int)(tn - tuples));
 }
 
 void emit(tuple *tn, FILE *fp)
@@ -799,7 +801,7 @@ void emit(tuple *tn, FILE *fp)
     case NEXT:
 	(void) fprintf(fp,
 		       "\tpushnext(%d); goto L%d; N%d:;\n",
-		       tn - tuples + 1, tn->u.target, tn - tuples + 1);
+		       (int)(tn - tuples + 1), tn->u.target, (int)(tn - tuples + 1));
 	break;
 
     case RESUME:
@@ -855,24 +857,38 @@ void emit(tuple *tn, FILE *fp)
 	break;
 
     case ENABLE:
+        (void) fprintf(fp,
+		       "\tint i;\n");
 	for (np = tn->u.node; np; np = np->rval)
 	{
 	    (void) fprintf(fp,
-			   "\tint i;\n\n\tfor (i = 0; i < (int)(sizeof(linetype)/sizeof(int)); i++)\n");
-	    (void) fprintf(fp,
-			   "\t    if (linetype[i] == %s)\n", enablers[np->constant-GETS]);
+			   "\n\tfor (i = 0; i < (int)(sizeof(linetype)/sizeof(int)); i++)\n");
+	    if (np->constant == ABSTAIN || np->constant == REINSTATE) {
+	      (void) fprintf(fp,
+			     "\t    if (linetype[i] == %s || linetype[i] == %s)\n", enablers[np->constant-GETS], enablers[np->constant-GETS+2]);
+	    } else {
+	      (void) fprintf(fp,
+			     "\t    if (linetype[i] == %s)\n", enablers[np->constant-GETS]);
+	    }
 	    (void) fprintf(fp,
 			   "\t\tabstained[i] = FALSE;\n");
 	}
 	break;
 
     case DISABLE:
+        (void) fprintf(fp,
+		       "\tint i;\n");
 	for (np = tn->u.node; np; np = np->rval)
 	{
 	    (void) fprintf(fp,
-			   "\tint i;\n\n\tfor (i = 0; i < (int)(sizeof(linetype)/sizeof(int)); i++)\n");
-	    (void) fprintf(fp,
-			   "\t    if (linetype[i] == %s)\n", enablers[np->constant-GETS]);
+			   "\n\tfor (i = 0; i < (int)(sizeof(linetype)/sizeof(int)); i++)\n");
+	    if (np->constant == ABSTAIN || np->constant == REINSTATE) {
+	      (void) fprintf(fp,
+			     "\t    if (linetype[i] == %s || linetype[i] == %s)\n", enablers[np->constant-GETS], enablers[np->constant-GETS+2]);
+	    } else {
+	      (void) fprintf(fp,
+			     "\t    if (linetype[i] == %s)\n", enablers[np->constant-GETS]);
+	    }
 	    (void) fprintf(fp,
 			   "\t\tabstained[i] = TRUE;\n");
 	}
